matminer.datasets.tests package — matminer 0.9.1 documentation

# matminer.datasets.tests package

## Submodules

## matminer.datasets.tests.base module

class matminer.datasets.tests.base.DatasetTest(methodName='runTest')

  Bases: `TestCase`

  setUp()

    Hook method for setting up the test fixture before exercising it.

## matminer.datasets.tests.test_convenience_loaders module

## matminer.datasets.tests.test_dataset_retrieval module

class matminer.datasets.tests.test_dataset_retrieval.DataRetrievalTest(methodName='runTest')

  Bases: `DatasetTest`

  test_get_all_dataset_info()
  test_get_dataset_attribute()
  test_get_dataset_citations()
  test_get_dataset_column_descriptions()
  test_get_dataset_columns()
  test_get_dataset_description()
  test_get_dataset_num_entries()
  test_get_dataset_reference()
  test_load_dataset()
  test_print_available_datasets()

## matminer.datasets.tests.test_datasets module

class matminer.datasets.tests.test_datasets.DataSetsTest(methodName='runTest')

  Bases: `DatasetTest`

  universal_dataset_check(dataset_name, object_headers=None, numeric_headers=None, bool_headers=None, test_func=None)

class matminer.datasets.tests.test_datasets.MatbenchDatasetsTest(methodName='runTest')

  Bases: `DataSetsTest`

  Matbench datasets are tested here.

  test_matbench_v0_1()

class matminer.datasets.tests.test_datasets.MatminerDatasetsTest(methodName='runTest')

  Bases: `DataSetsTest`

  All datasets hosted with matminer are tested here, excluding matbench datasets.

  test_boltztrap_mp()
  test_brgoch_superhard_training()
  test_castelli_perovskites()
  test_citrine_thermal_conductivity()
  test_dielectric_constant()
  test_double_perovskites_gap()
  test_double_perovskites_gap_lumo()
  test_elastic_tensor_2015()
  test_expt_formation_enthalpy()
  test_expt_formation_enthalpy_kingsbury()
  test_expt_gap()
  test_expt_gap_kingsbury()
  test_flla()
  test_glass_binary()
  test_glass_binary_v2()
  test_glass_ternary_hipt()
  test_glass_ternary_landolt()
  test_heusler_magnetic()
  test_jarvis_dft_2d()
  test_jarvis_dft_3d()
  test_jarvis_ml_dft_training()
  test_m2ax()
  test_mp_all_20181018()
  test_mp_nostruct_20181018()
  test_phonon_dielectric_mp()
  test_piezoelectric_tensor()
  test_ricci_boltztrap_mp_tabular()
  test_steel_strength()
  test_superconductivity2018()
  test_tholander_nitrides_e_form()
  test_ucsb_thermoelectrics()
  test_wolverton_oxides()

## matminer.datasets.tests.test_utils module

class matminer.datasets.tests.test_utils.UtilsTest(methodName='runTest')

  Bases: `DatasetTest`

  test_fetch_external_dataset()
  test_get_data_home()
  test_get_file_sha256_hash()
  test_load_dataset_dict()
  test_read_dataframe_from_file()
  test_validate_dataset()

## Module contents